@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.annotated_document import AnnotatedDocument
 from ...models.input_document import InputDocument
@@ -13,7 +15,7 @@ def _get_kwargs(
     annotator: str,
     *,
     client: Client,
-    json_body: List[InputDocument],
+    json_body: List["InputDocument"],
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
@@ -60,8 +62,8 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[AnnotatedDocument]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["AnnotatedDocument"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for componentsschemas_annotated_document_array_item_data in _response_200:
@@ -72,15 +74,18 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[AnnotatedDocum
             response_200.append(componentsschemas_annotated_document_array_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[AnnotatedDocument]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[List["AnnotatedDocument"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -89,14 +94,14 @@ def sync_detailed(
     annotator: str,
     *,
     client: Client,
-    json_body: List[InputDocument],
+    json_body: List["InputDocument"],
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
     debug: Union[Unset, None, bool] = False,
     parallelize: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = UNSET,
-) -> Response[List[AnnotatedDocument]]:
+) -> Response[List["AnnotatedDocument"]]:
     """Annotate documents with the given annotator
 
     Args:
@@ -108,10 +113,14 @@ def sync_detailed(
         debug (Union[Unset, None, bool]):
         parallelize (Union[Unset, None, bool]):
         output_fields (Union[Unset, None, str]):
-        json_body (List[InputDocument]):
+        json_body (List['InputDocument']):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[List[AnnotatedDocument]]
+        Response[List['AnnotatedDocument']]
     """
 
     kwargs = _get_kwargs(
@@ -132,7 +141,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -140,14 +149,14 @@ def sync(
     annotator: str,
     *,
     client: Client,
-    json_body: List[InputDocument],
+    json_body: List["InputDocument"],
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
     debug: Union[Unset, None, bool] = False,
     parallelize: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = UNSET,
-) -> Optional[List[AnnotatedDocument]]:
+) -> Optional[List["AnnotatedDocument"]]:
     """Annotate documents with the given annotator
 
     Args:
@@ -159,10 +168,14 @@ def sync(
         debug (Union[Unset, None, bool]):
         parallelize (Union[Unset, None, bool]):
         output_fields (Union[Unset, None, str]):
-        json_body (List[InputDocument]):
+        json_body (List['InputDocument']):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[List[AnnotatedDocument]]
+        Response[List['AnnotatedDocument']]
     """
 
     return sync_detailed(
@@ -184,14 +197,14 @@ async def asyncio_detailed(
     annotator: str,
     *,
     client: Client,
-    json_body: List[InputDocument],
+    json_body: List["InputDocument"],
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
     debug: Union[Unset, None, bool] = False,
     parallelize: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = UNSET,
-) -> Response[List[AnnotatedDocument]]:
+) -> Response[List["AnnotatedDocument"]]:
     """Annotate documents with the given annotator
 
     Args:
@@ -203,10 +216,14 @@ async def asyncio_detailed(
         debug (Union[Unset, None, bool]):
         parallelize (Union[Unset, None, bool]):
         output_fields (Union[Unset, None, str]):
-        json_body (List[InputDocument]):
+        json_body (List['InputDocument']):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[List[AnnotatedDocument]]
+        Response[List['AnnotatedDocument']]
     """
 
     kwargs = _get_kwargs(
@@ -225,7 +242,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -233,14 +250,14 @@ async def asyncio(
     annotator: str,
     *,
     client: Client,
-    json_body: List[InputDocument],
+    json_body: List["InputDocument"],
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
     debug: Union[Unset, None, bool] = False,
     parallelize: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = UNSET,
-) -> Optional[List[AnnotatedDocument]]:
+) -> Optional[List["AnnotatedDocument"]]:
     """Annotate documents with the given annotator
 
     Args:
@@ -252,10 +269,14 @@ async def asyncio(
         debug (Union[Unset, None, bool]):
         parallelize (Union[Unset, None, bool]):
         output_fields (Union[Unset, None, str]):
-        json_body (List[InputDocument]):
+        json_body (List['InputDocument']):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[List[AnnotatedDocument]]
+        Response[List['AnnotatedDocument']]
     """
 
     return (
