@@ -1,8 +1,10 @@
+from http import HTTPStatus
 from io import BytesIO
 from typing import Any, Dict, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.format_documents_with_many import FormatDocumentsWithMany
 from ...types import UNSET, File, Response, Unset
@@ -49,20 +51,23 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[File]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[File]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = File(payload=BytesIO(response.json()))
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[File]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[File]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -86,6 +91,10 @@ def sync_detailed(
         parallelize (Union[Unset, None, bool]):
         json_body (FormatDocumentsWithMany):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[File]
     """
@@ -105,7 +114,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -128,6 +137,10 @@ def sync(
         parallelize (Union[Unset, None, bool]):
         json_body (FormatDocumentsWithMany):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[File]
     """
@@ -163,6 +176,10 @@ async def asyncio_detailed(
         parallelize (Union[Unset, None, bool]):
         json_body (FormatDocumentsWithMany):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[File]
     """
@@ -180,7 +197,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -203,6 +220,10 @@ async def asyncio(
         parallelize (Union[Unset, None, bool]):
         json_body (FormatDocumentsWithMany):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[File]
     """
