@@ -1,8 +1,10 @@
+from http import HTTPStatus
 from io import BytesIO
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.input_document import InputDocument
 from ...types import UNSET, File, Response, Unset
@@ -13,7 +15,7 @@ def _get_kwargs(
     plan_name: str,
     *,
     client: Client,
-    json_body: List[InputDocument],
+    json_body: List["InputDocument"],
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
@@ -57,20 +59,23 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[File]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[File]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = File(payload=BytesIO(response.json()))
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[File]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[File]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -79,7 +84,7 @@ def sync_detailed(
     plan_name: str,
     *,
     client: Client,
-    json_body: List[InputDocument],
+    json_body: List["InputDocument"],
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
@@ -96,7 +101,11 @@ def sync_detailed(
         inline_text (Union[Unset, None, bool]):  Default: True.
         debug (Union[Unset, None, bool]):
         parallelize (Union[Unset, None, bool]):
-        json_body (List[InputDocument]):
+        json_body (List['InputDocument']):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[File]
@@ -119,7 +128,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -127,7 +136,7 @@ def sync(
     plan_name: str,
     *,
     client: Client,
-    json_body: List[InputDocument],
+    json_body: List["InputDocument"],
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
@@ -144,7 +153,11 @@ def sync(
         inline_text (Union[Unset, None, bool]):  Default: True.
         debug (Union[Unset, None, bool]):
         parallelize (Union[Unset, None, bool]):
-        json_body (List[InputDocument]):
+        json_body (List['InputDocument']):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[File]
@@ -168,7 +181,7 @@ async def asyncio_detailed(
     plan_name: str,
     *,
     client: Client,
-    json_body: List[InputDocument],
+    json_body: List["InputDocument"],
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
@@ -185,7 +198,11 @@ async def asyncio_detailed(
         inline_text (Union[Unset, None, bool]):  Default: True.
         debug (Union[Unset, None, bool]):
         parallelize (Union[Unset, None, bool]):
-        json_body (List[InputDocument]):
+        json_body (List['InputDocument']):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[File]
@@ -206,7 +223,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -214,7 +231,7 @@ async def asyncio(
     plan_name: str,
     *,
     client: Client,
-    json_body: List[InputDocument],
+    json_body: List["InputDocument"],
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
@@ -231,7 +248,11 @@ async def asyncio(
         inline_text (Union[Unset, None, bool]):  Default: True.
         debug (Union[Unset, None, bool]):
         parallelize (Union[Unset, None, bool]):
-        json_body (List[InputDocument]):
+        json_body (List['InputDocument']):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[File]
