@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.annotate_text_with_many import AnnotateTextWithMany
 from ...models.annotated_document import AnnotatedDocument
@@ -52,20 +54,23 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[AnnotatedDocument]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[AnnotatedDocument]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = AnnotatedDocument.from_dict(response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[AnnotatedDocument]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[AnnotatedDocument]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -91,6 +96,10 @@ def sync_detailed(
         output_fields (Union[Unset, None, str]):
         json_body (AnnotateTextWithMany):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[AnnotatedDocument]
     """
@@ -111,7 +120,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -136,6 +145,10 @@ def sync(
         output_fields (Union[Unset, None, str]):
         json_body (AnnotateTextWithMany):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[AnnotatedDocument]
     """
@@ -174,6 +187,10 @@ async def asyncio_detailed(
         output_fields (Union[Unset, None, str]):
         json_body (AnnotateTextWithMany):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[AnnotatedDocument]
     """
@@ -192,7 +209,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -217,6 +234,10 @@ async def asyncio(
         output_fields (Union[Unset, None, str]):
         json_body (AnnotateTextWithMany):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[AnnotatedDocument]
     """
