@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.operation_count import OperationCount
 from ...types import UNSET, Response, Unset
@@ -50,20 +52,23 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[OperationCount]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[OperationCount]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = OperationCount.from_dict(response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[OperationCount]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[OperationCount]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -81,6 +86,10 @@ def sync_detailed(
         labels (Union[Unset, None, List[str]]):
         created_by (Union[Unset, None, List[str]]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[OperationCount]
     """
@@ -97,7 +106,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -114,6 +123,10 @@ def sync(
         labels (Union[Unset, None, List[str]]):
         created_by (Union[Unset, None, List[str]]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[OperationCount]
     """
@@ -140,6 +153,10 @@ async def asyncio_detailed(
         labels (Union[Unset, None, List[str]]):
         created_by (Union[Unset, None, List[str]]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[OperationCount]
     """
@@ -154,7 +171,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -171,6 +188,10 @@ async def asyncio(
         labels (Union[Unset, None, List[str]]):
         created_by (Union[Unset, None, List[str]]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[OperationCount]
     """
