@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.document import Document
 from ...types import UNSET, Response, Unset
@@ -36,8 +38,8 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[Document]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["Document"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for componentsschemas_document_array_item_data in _response_200:
@@ -46,15 +48,18 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[Document]]:
             response_200.append(componentsschemas_document_array_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[Document]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[List["Document"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -64,7 +69,7 @@ def sync_detailed(
     client: Client,
     limit: Union[Unset, None, int] = 0,
     output_fields: Union[Unset, None, str] = UNSET,
-) -> Response[List[Document]]:
+) -> Response[List["Document"]]:
     """Get documents within project
 
     Args:
@@ -72,8 +77,12 @@ def sync_detailed(
         limit (Union[Unset, None, int]):
         output_fields (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Document]]
+        Response[List['Document']]
     """
 
     kwargs = _get_kwargs(
@@ -88,7 +97,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -97,7 +106,7 @@ def sync(
     client: Client,
     limit: Union[Unset, None, int] = 0,
     output_fields: Union[Unset, None, str] = UNSET,
-) -> Optional[List[Document]]:
+) -> Optional[List["Document"]]:
     """Get documents within project
 
     Args:
@@ -105,8 +114,12 @@ def sync(
         limit (Union[Unset, None, int]):
         output_fields (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Document]]
+        Response[List['Document']]
     """
 
     return sync_detailed(
@@ -123,7 +136,7 @@ async def asyncio_detailed(
     client: Client,
     limit: Union[Unset, None, int] = 0,
     output_fields: Union[Unset, None, str] = UNSET,
-) -> Response[List[Document]]:
+) -> Response[List["Document"]]:
     """Get documents within project
 
     Args:
@@ -131,8 +144,12 @@ async def asyncio_detailed(
         limit (Union[Unset, None, int]):
         output_fields (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Document]]
+        Response[List['Document']]
     """
 
     kwargs = _get_kwargs(
@@ -145,7 +162,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -154,7 +171,7 @@ async def asyncio(
     client: Client,
     limit: Union[Unset, None, int] = 0,
     output_fields: Union[Unset, None, str] = UNSET,
-) -> Optional[List[Document]]:
+) -> Optional[List["Document"]]:
     """Get documents within project
 
     Args:
@@ -162,8 +179,12 @@ async def asyncio(
         limit (Union[Unset, None, int]):
         output_fields (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Document]]
+        Response[List['Document']]
     """
 
     return (
