@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.document import Document
 from ...types import UNSET, Response, Unset
@@ -52,8 +54,8 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[Document]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["Document"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for componentsschemas_document_array_item_data in _response_200:
@@ -62,15 +64,18 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[Document]]:
             response_200.append(componentsschemas_document_array_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[Document]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[List["Document"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -83,7 +88,7 @@ def sync_detailed(
     simple_query: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = "",
     selected_facets: Union[Unset, None, List[str]] = UNSET,
-) -> Response[List[Document]]:
+) -> Response[List["Document"]]:
     """Search for documents and export them
 
     Args:
@@ -94,8 +99,12 @@ def sync_detailed(
         output_fields (Union[Unset, None, str]):  Default: ''.
         selected_facets (Union[Unset, None, List[str]]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Document]]
+        Response[List['Document']]
     """
 
     kwargs = _get_kwargs(
@@ -113,7 +122,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -125,7 +134,7 @@ def sync(
     simple_query: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = "",
     selected_facets: Union[Unset, None, List[str]] = UNSET,
-) -> Optional[List[Document]]:
+) -> Optional[List["Document"]]:
     """Search for documents and export them
 
     Args:
@@ -136,8 +145,12 @@ def sync(
         output_fields (Union[Unset, None, str]):  Default: ''.
         selected_facets (Union[Unset, None, List[str]]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Document]]
+        Response[List['Document']]
     """
 
     return sync_detailed(
@@ -160,7 +173,7 @@ async def asyncio_detailed(
     simple_query: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = "",
     selected_facets: Union[Unset, None, List[str]] = UNSET,
-) -> Response[List[Document]]:
+) -> Response[List["Document"]]:
     """Search for documents and export them
 
     Args:
@@ -171,8 +184,12 @@ async def asyncio_detailed(
         output_fields (Union[Unset, None, str]):  Default: ''.
         selected_facets (Union[Unset, None, List[str]]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Document]]
+        Response[List['Document']]
     """
 
     kwargs = _get_kwargs(
@@ -188,7 +205,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -200,7 +217,7 @@ async def asyncio(
     simple_query: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = "",
     selected_facets: Union[Unset, None, List[str]] = UNSET,
-) -> Optional[List[Document]]:
+) -> Optional[List["Document"]]:
     """Search for documents and export them
 
     Args:
@@ -211,8 +228,12 @@ async def asyncio(
         output_fields (Union[Unset, None, str]):  Default: ''.
         selected_facets (Union[Unset, None, List[str]]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Document]]
+        Response[List['Document']]
     """
 
     return (
