@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.sherpa_job_bean import SherpaJobBean
 from ...models.simple_metadata import SimpleMetadata
@@ -57,20 +59,23 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[SherpaJobBean]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[SherpaJobBean]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = SherpaJobBean.from_dict(response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[SherpaJobBean]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[SherpaJobBean]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -85,7 +90,7 @@ def sync_detailed(
     output_fields: Union[Unset, None, str] = "",
     selected_facets: Union[Unset, None, List[str]] = UNSET,
 ) -> Response[SherpaJobBean]:
-    """Search for documents and set a metadata value on them
+    """Search for documents and add/remove a metadata to/from all of them
 
     Args:
         project_name (str):
@@ -96,6 +101,10 @@ def sync_detailed(
         selected_facets (Union[Unset, None, List[str]]):
         json_body (SimpleMetadata):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[SherpaJobBean]
     """
@@ -116,7 +125,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -130,7 +139,7 @@ def sync(
     output_fields: Union[Unset, None, str] = "",
     selected_facets: Union[Unset, None, List[str]] = UNSET,
 ) -> Optional[SherpaJobBean]:
-    """Search for documents and set a metadata value on them
+    """Search for documents and add/remove a metadata to/from all of them
 
     Args:
         project_name (str):
@@ -141,6 +150,10 @@ def sync(
         selected_facets (Union[Unset, None, List[str]]):
         json_body (SimpleMetadata):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[SherpaJobBean]
     """
@@ -168,7 +181,7 @@ async def asyncio_detailed(
     output_fields: Union[Unset, None, str] = "",
     selected_facets: Union[Unset, None, List[str]] = UNSET,
 ) -> Response[SherpaJobBean]:
-    """Search for documents and set a metadata value on them
+    """Search for documents and add/remove a metadata to/from all of them
 
     Args:
         project_name (str):
@@ -179,6 +192,10 @@ async def asyncio_detailed(
         selected_facets (Union[Unset, None, List[str]]):
         json_body (SimpleMetadata):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[SherpaJobBean]
     """
@@ -197,7 +214,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -211,7 +228,7 @@ async def asyncio(
     output_fields: Union[Unset, None, str] = "",
     selected_facets: Union[Unset, None, List[str]] = UNSET,
 ) -> Optional[SherpaJobBean]:
-    """Search for documents and set a metadata value on them
+    """Search for documents and add/remove a metadata to/from all of them
 
     Args:
         project_name (str):
@@ -222,6 +239,10 @@ async def asyncio(
         selected_facets (Union[Unset, None, List[str]]):
         json_body (SimpleMetadata):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[SherpaJobBean]
     """
