@@ -1,8 +1,10 @@
+from http import HTTPStatus
 from io import BytesIO
 from typing import Any, Dict, Optional
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...types import File, Response
 
@@ -29,20 +31,23 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[File]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[File]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = File(payload=BytesIO(response.content))
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[File]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[File]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -58,6 +63,10 @@ def sync_detailed(
         project_name (str):
         name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[File]
     """
@@ -73,7 +82,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -88,6 +97,10 @@ def sync(
         project_name (str):
         name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[File]
     """
@@ -111,6 +124,10 @@ async def asyncio_detailed(
         project_name (str):
         name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[File]
     """
@@ -124,7 +141,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -139,6 +156,10 @@ async def asyncio(
         project_name (str):
         name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[File]
     """
