@@ -1,9 +1,12 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional, Union, cast
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.gazetteer import Gazetteer
+from ...models.gazetteer_patch import GazetteerPatch
 from ...types import Response
 
 
@@ -12,38 +15,45 @@ def _get_kwargs(
     name: str,
     *,
     client: Client,
+    json_body: GazetteerPatch,
 ) -> Dict[str, Any]:
     url = "{}/projects/{projectName}/gazetteers/{name}".format(client.base_url, projectName=project_name, name=name)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
+    json_json_body = json_body.to_dict()
+
     return {
         "method": "patch",
         "url": url,
         "headers": headers,
         "cookies": cookies,
         "timeout": client.get_timeout(),
+        "json": json_json_body,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, Gazetteer]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[Any, Gazetteer]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = Gazetteer.from_dict(response.json())
 
         return response_200
-    if response.status_code == 404:
+    if response.status_code == HTTPStatus.NOT_FOUND:
         response_404 = cast(Any, None)
         return response_404
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[Union[Any, Gazetteer]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[Any, Gazetteer]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -52,12 +62,18 @@ def sync_detailed(
     name: str,
     *,
     client: Client,
+    json_body: GazetteerPatch,
 ) -> Response[Union[Any, Gazetteer]]:
     """Partially update a gazetteer
 
     Args:
         project_name (str):
         name (str):
+        json_body (GazetteerPatch):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Any, Gazetteer]]
@@ -67,6 +83,7 @@ def sync_detailed(
         project_name=project_name,
         name=name,
         client=client,
+        json_body=json_body,
     )
 
     response = httpx.request(
@@ -74,7 +91,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -82,12 +99,18 @@ def sync(
     name: str,
     *,
     client: Client,
+    json_body: GazetteerPatch,
 ) -> Optional[Union[Any, Gazetteer]]:
     """Partially update a gazetteer
 
     Args:
         project_name (str):
         name (str):
+        json_body (GazetteerPatch):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Any, Gazetteer]]
@@ -97,6 +120,7 @@ def sync(
         project_name=project_name,
         name=name,
         client=client,
+        json_body=json_body,
     ).parsed
 
 
@@ -105,12 +129,18 @@ async def asyncio_detailed(
     name: str,
     *,
     client: Client,
+    json_body: GazetteerPatch,
 ) -> Response[Union[Any, Gazetteer]]:
     """Partially update a gazetteer
 
     Args:
         project_name (str):
         name (str):
+        json_body (GazetteerPatch):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Any, Gazetteer]]
@@ -120,12 +150,13 @@ async def asyncio_detailed(
         project_name=project_name,
         name=name,
         client=client,
+        json_body=json_body,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -133,12 +164,18 @@ async def asyncio(
     name: str,
     *,
     client: Client,
+    json_body: GazetteerPatch,
 ) -> Optional[Union[Any, Gazetteer]]:
     """Partially update a gazetteer
 
     Args:
         project_name (str):
         name (str):
+        json_body (GazetteerPatch):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Any, Gazetteer]]
@@ -149,5 +186,6 @@ async def asyncio(
             project_name=project_name,
             name=name,
             client=client,
+            json_body=json_body,
         )
     ).parsed
