@@ -1,10 +1,12 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional, Union, cast
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.sherpa_job_bean import SherpaJobBean
-from ...types import Response
+from ...types import UNSET, Response, Unset
 
 
 def _get_kwargs(
@@ -12,6 +14,7 @@ def _get_kwargs(
     name: str,
     *,
     client: Client,
+    annotate_corpus: Union[Unset, None, bool] = False,
 ) -> Dict[str, Any]:
     url = "{}/projects/{projectName}/gazetteers/{name}/_synchronize".format(
         client.base_url, projectName=project_name, name=name
@@ -20,32 +23,41 @@ def _get_kwargs(
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
+    params: Dict[str, Any] = {}
+    params["annotateCorpus"] = annotate_corpus
+
+    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
+
     return {
         "method": "post",
         "url": url,
         "headers": headers,
         "cookies": cookies,
         "timeout": client.get_timeout(),
+        "params": params,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, SherpaJobBean]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[Any, SherpaJobBean]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = SherpaJobBean.from_dict(response.json())
 
         return response_200
-    if response.status_code == 404:
+    if response.status_code == HTTPStatus.NOT_FOUND:
         response_404 = cast(Any, None)
         return response_404
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[Union[Any, SherpaJobBean]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[Any, SherpaJobBean]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -54,12 +66,18 @@ def sync_detailed(
     name: str,
     *,
     client: Client,
+    annotate_corpus: Union[Unset, None, bool] = False,
 ) -> Response[Union[Any, SherpaJobBean]]:
-    """Launch a synchronize
+    """Build the gazetteer model from the lexicon
 
     Args:
         project_name (str):
         name (str):
+        annotate_corpus (Union[Unset, None, bool]):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Any, SherpaJobBean]]
@@ -69,6 +87,7 @@ def sync_detailed(
         project_name=project_name,
         name=name,
         client=client,
+        annotate_corpus=annotate_corpus,
     )
 
     response = httpx.request(
@@ -76,7 +95,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -84,12 +103,18 @@ def sync(
     name: str,
     *,
     client: Client,
+    annotate_corpus: Union[Unset, None, bool] = False,
 ) -> Optional[Union[Any, SherpaJobBean]]:
-    """Launch a synchronize
+    """Build the gazetteer model from the lexicon
 
     Args:
         project_name (str):
         name (str):
+        annotate_corpus (Union[Unset, None, bool]):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Any, SherpaJobBean]]
@@ -99,6 +124,7 @@ def sync(
         project_name=project_name,
         name=name,
         client=client,
+        annotate_corpus=annotate_corpus,
     ).parsed
 
 
@@ -107,12 +133,18 @@ async def asyncio_detailed(
     name: str,
     *,
     client: Client,
+    annotate_corpus: Union[Unset, None, bool] = False,
 ) -> Response[Union[Any, SherpaJobBean]]:
-    """Launch a synchronize
+    """Build the gazetteer model from the lexicon
 
     Args:
         project_name (str):
         name (str):
+        annotate_corpus (Union[Unset, None, bool]):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Any, SherpaJobBean]]
@@ -122,12 +154,13 @@ async def asyncio_detailed(
         project_name=project_name,
         name=name,
         client=client,
+        annotate_corpus=annotate_corpus,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -135,12 +168,18 @@ async def asyncio(
     name: str,
     *,
     client: Client,
+    annotate_corpus: Union[Unset, None, bool] = False,
 ) -> Optional[Union[Any, SherpaJobBean]]:
-    """Launch a synchronize
+    """Build the gazetteer model from the lexicon
 
     Args:
         project_name (str):
         name (str):
+        annotate_corpus (Union[Unset, None, bool]):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Any, SherpaJobBean]]
@@ -151,5 +190,6 @@ async def asyncio(
             project_name=project_name,
             name=name,
             client=client,
+            annotate_corpus=annotate_corpus,
         )
     ).parsed
