@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.group_desc import GroupDesc
 from ...types import Response
@@ -25,8 +27,8 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[GroupDesc]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["GroupDesc"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for componentsschemas_group_desc_array_item_data in _response_200:
@@ -35,26 +37,33 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[GroupDesc]]:
             response_200.append(componentsschemas_group_desc_array_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[GroupDesc]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[List["GroupDesc"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
 def sync_detailed(
     *,
     client: Client,
-) -> Response[List[GroupDesc]]:
+) -> Response[List["GroupDesc"]]:
     """Get users' groups
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[GroupDesc]]
+        Response[List['GroupDesc']]
     """
 
     kwargs = _get_kwargs(
@@ -66,17 +75,21 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     *,
     client: Client,
-) -> Optional[List[GroupDesc]]:
+) -> Optional[List["GroupDesc"]]:
     """Get users' groups
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[GroupDesc]]
+        Response[List['GroupDesc']]
     """
 
     return sync_detailed(
@@ -87,11 +100,15 @@ def sync(
 async def asyncio_detailed(
     *,
     client: Client,
-) -> Response[List[GroupDesc]]:
+) -> Response[List["GroupDesc"]]:
     """Get users' groups
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[GroupDesc]]
+        Response[List['GroupDesc']]
     """
 
     kwargs = _get_kwargs(
@@ -101,17 +118,21 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     *,
     client: Client,
-) -> Optional[List[GroupDesc]]:
+) -> Optional[List["GroupDesc"]]:
     """Get users' groups
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[GroupDesc]]
+        Response[List['GroupDesc']]
     """
 
     return (
