@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.label import Label
 from ...types import UNSET, Response, Unset
@@ -12,6 +14,7 @@ def _get_kwargs(
     *,
     client: Client,
     include_count: Union[Unset, None, bool] = False,
+    label_set_name: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/projects/{projectName}/labels".format(client.base_url, projectName=project_name)
 
@@ -21,6 +24,8 @@ def _get_kwargs(
     params: Dict[str, Any] = {}
     params["includeCount"] = include_count
 
+    params["labelSetName"] = label_set_name
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -33,8 +38,8 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[Label]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["Label"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for componentsschemas_label_array_item_data in _response_200:
@@ -43,15 +48,18 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[Label]]:
             response_200.append(componentsschemas_label_array_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[Label]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[List["Label"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -60,21 +68,28 @@ def sync_detailed(
     *,
     client: Client,
     include_count: Union[Unset, None, bool] = False,
-) -> Response[List[Label]]:
+    label_set_name: Union[Unset, None, str] = UNSET,
+) -> Response[List["Label"]]:
     """Get labels
 
     Args:
         project_name (str):
         include_count (Union[Unset, None, bool]):
+        label_set_name (Union[Unset, None, str]):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[List[Label]]
+        Response[List['Label']]
     """
 
     kwargs = _get_kwargs(
         project_name=project_name,
         client=client,
         include_count=include_count,
+        label_set_name=label_set_name,
     )
 
     response = httpx.request(
@@ -82,7 +97,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -90,21 +105,28 @@ def sync(
     *,
     client: Client,
     include_count: Union[Unset, None, bool] = False,
-) -> Optional[List[Label]]:
+    label_set_name: Union[Unset, None, str] = UNSET,
+) -> Optional[List["Label"]]:
     """Get labels
 
     Args:
         project_name (str):
         include_count (Union[Unset, None, bool]):
+        label_set_name (Union[Unset, None, str]):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[List[Label]]
+        Response[List['Label']]
     """
 
     return sync_detailed(
         project_name=project_name,
         client=client,
         include_count=include_count,
+        label_set_name=label_set_name,
     ).parsed
 
 
@@ -113,27 +135,34 @@ async def asyncio_detailed(
     *,
     client: Client,
     include_count: Union[Unset, None, bool] = False,
-) -> Response[List[Label]]:
+    label_set_name: Union[Unset, None, str] = UNSET,
+) -> Response[List["Label"]]:
     """Get labels
 
     Args:
         project_name (str):
         include_count (Union[Unset, None, bool]):
+        label_set_name (Union[Unset, None, str]):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[List[Label]]
+        Response[List['Label']]
     """
 
     kwargs = _get_kwargs(
         project_name=project_name,
         client=client,
         include_count=include_count,
+        label_set_name=label_set_name,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -141,15 +170,21 @@ async def asyncio(
     *,
     client: Client,
     include_count: Union[Unset, None, bool] = False,
-) -> Optional[List[Label]]:
+    label_set_name: Union[Unset, None, str] = UNSET,
+) -> Optional[List["Label"]]:
     """Get labels
 
     Args:
         project_name (str):
         include_count (Union[Unset, None, bool]):
+        label_set_name (Union[Unset, None, str]):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[List[Label]]
+        Response[List['Label']]
     """
 
     return (
@@ -157,5 +192,6 @@ async def asyncio(
             project_name=project_name,
             client=client,
             include_count=include_count,
+            label_set_name=label_set_name,
         )
     ).parsed
