@@ -1,10 +1,12 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional
 
 import httpx
 
+from ... import errors
 from ...client import Client
+from ...models.create_term_json_body import CreateTermJsonBody
 from ...models.create_term_response_200 import CreateTermResponse200
-from ...models.term import Term
 from ...types import Response
 
 
@@ -13,7 +15,7 @@ def _get_kwargs(
     lexicon_name: str,
     *,
     client: Client,
-    json_body: Term,
+    json_body: CreateTermJsonBody,
 ) -> Dict[str, Any]:
     url = "{}/projects/{projectName}/lexicons/{lexiconName}".format(
         client.base_url, projectName=project_name, lexiconName=lexicon_name
@@ -34,20 +36,23 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[CreateTermResponse200]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[CreateTermResponse200]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = CreateTermResponse200.from_dict(response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[CreateTermResponse200]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[CreateTermResponse200]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -56,14 +61,18 @@ def sync_detailed(
     lexicon_name: str,
     *,
     client: Client,
-    json_body: Term,
+    json_body: CreateTermJsonBody,
 ) -> Response[CreateTermResponse200]:
     """Create a new term in the lexicon
 
     Args:
         project_name (str):
         lexicon_name (str):
-        json_body (Term):
+        json_body (CreateTermJsonBody):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[CreateTermResponse200]
@@ -81,7 +90,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -89,14 +98,18 @@ def sync(
     lexicon_name: str,
     *,
     client: Client,
-    json_body: Term,
+    json_body: CreateTermJsonBody,
 ) -> Optional[CreateTermResponse200]:
     """Create a new term in the lexicon
 
     Args:
         project_name (str):
         lexicon_name (str):
-        json_body (Term):
+        json_body (CreateTermJsonBody):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[CreateTermResponse200]
@@ -115,14 +128,18 @@ async def asyncio_detailed(
     lexicon_name: str,
     *,
     client: Client,
-    json_body: Term,
+    json_body: CreateTermJsonBody,
 ) -> Response[CreateTermResponse200]:
     """Create a new term in the lexicon
 
     Args:
         project_name (str):
         lexicon_name (str):
-        json_body (Term):
+        json_body (CreateTermJsonBody):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[CreateTermResponse200]
@@ -138,7 +155,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -146,14 +163,18 @@ async def asyncio(
     lexicon_name: str,
     *,
     client: Client,
-    json_body: Term,
+    json_body: CreateTermJsonBody,
 ) -> Optional[CreateTermResponse200]:
     """Create a new term in the lexicon
 
     Args:
         project_name (str):
         lexicon_name (str):
-        json_body (Term):
+        json_body (CreateTermJsonBody):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[CreateTermResponse200]
