@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional, Union, cast
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.sherpa_job_bean import SherpaJobBean
 from ...models.term_import import TermImport
@@ -34,23 +36,26 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, SherpaJobBean]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[Any, SherpaJobBean]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = SherpaJobBean.from_dict(response.json())
 
         return response_200
-    if response.status_code == 404:
+    if response.status_code == HTTPStatus.NOT_FOUND:
         response_404 = cast(Any, None)
         return response_404
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[Union[Any, SherpaJobBean]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[Any, SherpaJobBean]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -68,6 +73,10 @@ def sync_detailed(
         lexicon_name (str):
         json_body (TermImport):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Union[Any, SherpaJobBean]]
     """
@@ -84,7 +93,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -101,6 +110,10 @@ def sync(
         lexicon_name (str):
         json_body (TermImport):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Union[Any, SherpaJobBean]]
     """
@@ -127,6 +140,10 @@ async def asyncio_detailed(
         lexicon_name (str):
         json_body (TermImport):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Union[Any, SherpaJobBean]]
     """
@@ -141,7 +158,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -158,6 +175,10 @@ async def asyncio(
         lexicon_name (str):
         json_body (TermImport):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Union[Any, SherpaJobBean]]
     """
