@@ -1,7 +1,9 @@
-from typing import Any, Dict
+from http import HTTPStatus
+from typing import Any, Dict, Optional
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...types import UNSET, Response
 
@@ -32,12 +34,21 @@ def _get_kwargs(
     }
 
 
-def _build_response(*, response: httpx.Response) -> Response[Any]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Any]:
+    if response.status_code == HTTPStatus.NO_CONTENT:
+        return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
+
+
+def _build_response(*, client: Client, response: httpx.Response) -> Response[Any]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=None,
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -53,6 +64,10 @@ def sync_detailed(
         project_name (str):
         mode (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Any]
     """
@@ -68,7 +83,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio_detailed(
@@ -83,6 +98,10 @@ async def asyncio_detailed(
         project_name (str):
         mode (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Any]
     """
@@ -96,4 +115,4 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
