@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.create_project_from_archive_multipart_data import CreateProjectFromArchiveMultipartData
 from ...models.sherpa_job_bean import SherpaJobBean
@@ -46,20 +48,23 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[SherpaJobBean]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[SherpaJobBean]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = SherpaJobBean.from_dict(response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[SherpaJobBean]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[SherpaJobBean]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -81,6 +86,10 @@ def sync_detailed(
         project_label (Union[Unset, None, str]):
         multipart_data (CreateProjectFromArchiveMultipartData):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[SherpaJobBean]
     """
@@ -99,7 +108,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -120,6 +129,10 @@ def sync(
         project_label (Union[Unset, None, str]):
         multipart_data (CreateProjectFromArchiveMultipartData):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[SherpaJobBean]
     """
@@ -152,6 +165,10 @@ async def asyncio_detailed(
         project_label (Union[Unset, None, str]):
         multipart_data (CreateProjectFromArchiveMultipartData):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[SherpaJobBean]
     """
@@ -168,7 +185,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -189,6 +206,10 @@ async def asyncio(
         project_label (Union[Unset, None, str]):
         multipart_data (CreateProjectFromArchiveMultipartData):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[SherpaJobBean]
     """
