@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.project_status import ProjectStatus
 from ...types import Response
@@ -25,20 +27,23 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[ProjectStatus]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[ProjectStatus]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = ProjectStatus.from_dict(response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[ProjectStatus]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[ProjectStatus]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -48,6 +53,10 @@ def sync_detailed(
 ) -> Response[ProjectStatus]:
     """create a specific tour project for the current user
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[ProjectStatus]
     """
@@ -61,7 +70,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -70,6 +79,10 @@ def sync(
 ) -> Optional[ProjectStatus]:
     """create a specific tour project for the current user
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[ProjectStatus]
     """
@@ -85,6 +98,10 @@ async def asyncio_detailed(
 ) -> Response[ProjectStatus]:
     """create a specific tour project for the current user
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[ProjectStatus]
     """
@@ -96,7 +113,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -105,6 +122,10 @@ async def asyncio(
 ) -> Optional[ProjectStatus]:
     """create a specific tour project for the current user
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[ProjectStatus]
     """
