@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.segment import Segment
 from ...types import Response
@@ -26,8 +28,8 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[Segment]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["Segment"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for componentsschemas_segment_array_item_data in _response_200:
@@ -36,15 +38,18 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[Segment]]:
             response_200.append(componentsschemas_segment_array_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[Segment]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[List["Segment"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -52,14 +57,18 @@ def sync_detailed(
     project_name: str,
     *,
     client: Client,
-) -> Response[List[Segment]]:
+) -> Response[List["Segment"]]:
     """get the dataset of the project
 
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Segment]]
+        Response[List['Segment']]
     """
 
     kwargs = _get_kwargs(
@@ -72,21 +81,25 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     project_name: str,
     *,
     client: Client,
-) -> Optional[List[Segment]]:
+) -> Optional[List["Segment"]]:
     """get the dataset of the project
 
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Segment]]
+        Response[List['Segment']]
     """
 
     return sync_detailed(
@@ -99,14 +112,18 @@ async def asyncio_detailed(
     project_name: str,
     *,
     client: Client,
-) -> Response[List[Segment]]:
+) -> Response[List["Segment"]]:
     """get the dataset of the project
 
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Segment]]
+        Response[List['Segment']]
     """
 
     kwargs = _get_kwargs(
@@ -117,21 +134,25 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     project_name: str,
     *,
     client: Client,
-) -> Optional[List[Segment]]:
+) -> Optional[List["Segment"]]:
     """get the dataset of the project
 
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[Segment]]
+        Response[List['Segment']]
     """
 
     return (
