@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.metadata_definition import MetadataDefinition
 from ...types import Response
@@ -26,8 +28,8 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[MetadataDefinition]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["MetadataDefinition"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for componentsschemas_metadata_definition_array_item_data in _response_200:
@@ -38,15 +40,18 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[MetadataDefini
             response_200.append(componentsschemas_metadata_definition_array_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[MetadataDefinition]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[List["MetadataDefinition"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -54,14 +59,18 @@ def sync_detailed(
     project_name: str,
     *,
     client: Client,
-) -> Response[List[MetadataDefinition]]:
+) -> Response[List["MetadataDefinition"]]:
     """get the list of known metadata in this project
 
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[MetadataDefinition]]
+        Response[List['MetadataDefinition']]
     """
 
     kwargs = _get_kwargs(
@@ -74,21 +83,25 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     project_name: str,
     *,
     client: Client,
-) -> Optional[List[MetadataDefinition]]:
+) -> Optional[List["MetadataDefinition"]]:
     """get the list of known metadata in this project
 
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[MetadataDefinition]]
+        Response[List['MetadataDefinition']]
     """
 
     return sync_detailed(
@@ -101,14 +114,18 @@ async def asyncio_detailed(
     project_name: str,
     *,
     client: Client,
-) -> Response[List[MetadataDefinition]]:
+) -> Response[List["MetadataDefinition"]]:
     """get the list of known metadata in this project
 
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[MetadataDefinition]]
+        Response[List['MetadataDefinition']]
     """
 
     kwargs = _get_kwargs(
@@ -119,21 +136,25 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     project_name: str,
     *,
     client: Client,
-) -> Optional[List[MetadataDefinition]]:
+) -> Optional[List["MetadataDefinition"]]:
     """get the list of known metadata in this project
 
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[MetadataDefinition]]
+        Response[List['MetadataDefinition']]
     """
 
     return (
