@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.project_property import ProjectProperty
 from ...types import Response
@@ -26,20 +28,23 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[ProjectProperty]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[ProjectProperty]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = ProjectProperty.from_dict(response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[ProjectProperty]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[ProjectProperty]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -53,6 +58,10 @@ def sync_detailed(
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[ProjectProperty]
     """
@@ -67,7 +76,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -80,6 +89,10 @@ def sync(
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[ProjectProperty]
     """
@@ -100,6 +113,10 @@ async def asyncio_detailed(
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[ProjectProperty]
     """
@@ -112,7 +129,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -125,6 +142,10 @@ async def asyncio(
     Args:
         project_name (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[ProjectProperty]
     """
