@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.maybe_create_projects_and_import_models_from_archive_multipart_data import (
     MaybeCreateProjectsAndImportModelsFromArchiveMultipartData,
@@ -48,8 +50,8 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[ProjectStatus]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["ProjectStatus"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for componentsschemas_project_status_array_item_data in _response_200:
@@ -60,15 +62,18 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[ProjectStatus]
             response_200.append(componentsschemas_project_status_array_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[ProjectStatus]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[List["ProjectStatus"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -80,7 +85,7 @@ def sync_detailed(
     reuse_project_name: Union[Unset, None, bool] = False,
     project_name: Union[Unset, None, str] = UNSET,
     project_label: Union[Unset, None, str] = UNSET,
-) -> Response[List[ProjectStatus]]:
+) -> Response[List["ProjectStatus"]]:
     """import models (and create projects if required)
 
     Args:
@@ -90,8 +95,12 @@ def sync_detailed(
         project_label (Union[Unset, None, str]):
         multipart_data (MaybeCreateProjectsAndImportModelsFromArchiveMultipartData):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ProjectStatus]]
+        Response[List['ProjectStatus']]
     """
 
     kwargs = _get_kwargs(
@@ -108,7 +117,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -119,7 +128,7 @@ def sync(
     reuse_project_name: Union[Unset, None, bool] = False,
     project_name: Union[Unset, None, str] = UNSET,
     project_label: Union[Unset, None, str] = UNSET,
-) -> Optional[List[ProjectStatus]]:
+) -> Optional[List["ProjectStatus"]]:
     """import models (and create projects if required)
 
     Args:
@@ -129,8 +138,12 @@ def sync(
         project_label (Union[Unset, None, str]):
         multipart_data (MaybeCreateProjectsAndImportModelsFromArchiveMultipartData):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ProjectStatus]]
+        Response[List['ProjectStatus']]
     """
 
     return sync_detailed(
@@ -151,7 +164,7 @@ async def asyncio_detailed(
     reuse_project_name: Union[Unset, None, bool] = False,
     project_name: Union[Unset, None, str] = UNSET,
     project_label: Union[Unset, None, str] = UNSET,
-) -> Response[List[ProjectStatus]]:
+) -> Response[List["ProjectStatus"]]:
     """import models (and create projects if required)
 
     Args:
@@ -161,8 +174,12 @@ async def asyncio_detailed(
         project_label (Union[Unset, None, str]):
         multipart_data (MaybeCreateProjectsAndImportModelsFromArchiveMultipartData):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ProjectStatus]]
+        Response[List['ProjectStatus']]
     """
 
     kwargs = _get_kwargs(
@@ -177,7 +194,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -188,7 +205,7 @@ async def asyncio(
     reuse_project_name: Union[Unset, None, bool] = False,
     project_name: Union[Unset, None, str] = UNSET,
     project_label: Union[Unset, None, str] = UNSET,
-) -> Optional[List[ProjectStatus]]:
+) -> Optional[List["ProjectStatus"]]:
     """import models (and create projects if required)
 
     Args:
@@ -198,8 +215,12 @@ async def asyncio(
         project_label (Union[Unset, None, str]):
         multipart_data (MaybeCreateProjectsAndImportModelsFromArchiveMultipartData):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ProjectStatus]]
+        Response[List['ProjectStatus']]
     """
 
     return (
