@@ -1,7 +1,9 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.get_services_distinct_values_response_200_item import GetServicesDistinctValuesResponse200Item
 from ...types import UNSET, Response, Unset
@@ -71,8 +73,10 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[GetServicesDistinctValuesResponse200Item]]:
-    if response.status_code == 200:
+def _parse_response(
+    *, client: Client, response: httpx.Response
+) -> Optional[List["GetServicesDistinctValuesResponse200Item"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for response_200_item_data in _response_200:
@@ -81,15 +85,20 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[GetServicesDis
             response_200.append(response_200_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[GetServicesDistinctValuesResponse200Item]]:
+def _build_response(
+    *, client: Client, response: httpx.Response
+) -> Response[List["GetServicesDistinctValuesResponse200Item"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -110,7 +119,7 @@ def sync_detailed(
     processor: Union[Unset, None, str] = "",
     formatter: Union[Unset, None, str] = "",
     converter: Union[Unset, None, str] = "",
-) -> Response[List[GetServicesDistinctValuesResponse200Item]]:
+) -> Response[List["GetServicesDistinctValuesResponse200Item"]]:
     """Filter the list of available services and return distinct values
 
     Args:
@@ -129,8 +138,12 @@ def sync_detailed(
         formatter (Union[Unset, None, str]):  Default: ''.
         converter (Union[Unset, None, str]):  Default: ''.
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[GetServicesDistinctValuesResponse200Item]]
+        Response[List['GetServicesDistinctValuesResponse200Item']]
     """
 
     kwargs = _get_kwargs(
@@ -156,7 +169,7 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -176,7 +189,7 @@ def sync(
     processor: Union[Unset, None, str] = "",
     formatter: Union[Unset, None, str] = "",
     converter: Union[Unset, None, str] = "",
-) -> Optional[List[GetServicesDistinctValuesResponse200Item]]:
+) -> Optional[List["GetServicesDistinctValuesResponse200Item"]]:
     """Filter the list of available services and return distinct values
 
     Args:
@@ -195,8 +208,12 @@ def sync(
         formatter (Union[Unset, None, str]):  Default: ''.
         converter (Union[Unset, None, str]):  Default: ''.
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[GetServicesDistinctValuesResponse200Item]]
+        Response[List['GetServicesDistinctValuesResponse200Item']]
     """
 
     return sync_detailed(
@@ -235,7 +252,7 @@ async def asyncio_detailed(
     processor: Union[Unset, None, str] = "",
     formatter: Union[Unset, None, str] = "",
     converter: Union[Unset, None, str] = "",
-) -> Response[List[GetServicesDistinctValuesResponse200Item]]:
+) -> Response[List["GetServicesDistinctValuesResponse200Item"]]:
     """Filter the list of available services and return distinct values
 
     Args:
@@ -254,8 +271,12 @@ async def asyncio_detailed(
         formatter (Union[Unset, None, str]):  Default: ''.
         converter (Union[Unset, None, str]):  Default: ''.
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[GetServicesDistinctValuesResponse200Item]]
+        Response[List['GetServicesDistinctValuesResponse200Item']]
     """
 
     kwargs = _get_kwargs(
@@ -279,7 +300,7 @@ async def asyncio_detailed(
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -299,7 +320,7 @@ async def asyncio(
     processor: Union[Unset, None, str] = "",
     formatter: Union[Unset, None, str] = "",
     converter: Union[Unset, None, str] = "",
-) -> Optional[List[GetServicesDistinctValuesResponse200Item]]:
+) -> Optional[List["GetServicesDistinctValuesResponse200Item"]]:
     """Filter the list of available services and return distinct values
 
     Args:
@@ -318,8 +339,12 @@ async def asyncio(
         formatter (Union[Unset, None, str]):  Default: ''.
         converter (Union[Unset, None, str]):  Default: ''.
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[GetServicesDistinctValuesResponse200Item]]
+        Response[List['GetServicesDistinctValuesResponse200Item']]
     """
 
     return (
