@@ -1,9 +1,12 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional, Union, cast
 
 import httpx
 
+from ... import errors
 from ...client import Client
 from ...models.ack import Ack
+from ...models.user_permissions_update import UserPermissionsUpdate
 from ...types import Response
 
 
@@ -11,38 +14,45 @@ def _get_kwargs(
     username: str,
     *,
     client: Client,
+    json_body: UserPermissionsUpdate,
 ) -> Dict[str, Any]:
     url = "{}/users/{username}".format(client.base_url, username=username)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
+    json_json_body = json_body.to_dict()
+
     return {
         "method": "patch",
         "url": url,
         "headers": headers,
         "cookies": cookies,
         "timeout": client.get_timeout(),
+        "json": json_json_body,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[Union[Ack, Any]]:
-    if response.status_code == 200:
+def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[Ack, Any]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = Ack.from_dict(response.json())
 
         return response_200
-    if response.status_code == 404:
+    if response.status_code == HTTPStatus.NOT_FOUND:
         response_404 = cast(Any, None)
         return response_404
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[Union[Ack, Any]]:
+def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[Ack, Any]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -50,11 +60,17 @@ def sync_detailed(
     username: str,
     *,
     client: Client,
+    json_body: UserPermissionsUpdate,
 ) -> Response[Union[Ack, Any]]:
     """Update user roles or permissions
 
     Args:
         username (str):
+        json_body (UserPermissionsUpdate):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Ack, Any]]
@@ -63,6 +79,7 @@ def sync_detailed(
     kwargs = _get_kwargs(
         username=username,
         client=client,
+        json_body=json_body,
     )
 
     response = httpx.request(
@@ -70,18 +87,24 @@ def sync_detailed(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     username: str,
     *,
     client: Client,
+    json_body: UserPermissionsUpdate,
 ) -> Optional[Union[Ack, Any]]:
     """Update user roles or permissions
 
     Args:
         username (str):
+        json_body (UserPermissionsUpdate):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Ack, Any]]
@@ -90,6 +113,7 @@ def sync(
     return sync_detailed(
         username=username,
         client=client,
+        json_body=json_body,
     ).parsed
 
 
@@ -97,11 +121,17 @@ async def asyncio_detailed(
     username: str,
     *,
     client: Client,
+    json_body: UserPermissionsUpdate,
 ) -> Response[Union[Ack, Any]]:
     """Update user roles or permissions
 
     Args:
         username (str):
+        json_body (UserPermissionsUpdate):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Ack, Any]]
@@ -110,23 +140,30 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         username=username,
         client=client,
+        json_body=json_body,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
         response = await _client.request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     username: str,
     *,
     client: Client,
+    json_body: UserPermissionsUpdate,
 ) -> Optional[Union[Ack, Any]]:
     """Update user roles or permissions
 
     Args:
         username (str):
+        json_body (UserPermissionsUpdate):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
         Response[Union[Ack, Any]]
@@ -136,5 +173,6 @@ async def asyncio(
         await asyncio_detailed(
             username=username,
             client=client,
+            json_body=json_body,
         )
     ).parsed
