@@ -12,35 +12,34 @@ class Annotator:
     """
     Attributes:
         engine (str):
+        favorite (bool):
         label (str):
         name (str):
-        favorite (Union[Unset, bool]):
         is_default (Union[Unset, bool]):
     """
 
     engine: str
+    favorite: bool
     label: str
     name: str
-    favorite: Union[Unset, bool] = UNSET
     is_default: Union[Unset, bool] = UNSET
 
     def to_dict(self) -> Dict[str, Any]:
         engine = self.engine
+        favorite = self.favorite
         label = self.label
         name = self.name
-        favorite = self.favorite
         is_default = self.is_default
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(
             {
                 "engine": engine,
+                "favorite": favorite,
                 "label": label,
                 "name": name,
             }
         )
-        if favorite is not UNSET:
-            field_dict["favorite"] = favorite
         if is_default is not UNSET:
             field_dict["isDefault"] = is_default
 
@@ -51,19 +50,19 @@ class Annotator:
         d = src_dict.copy()
         engine = d.pop("engine")
 
+        favorite = d.pop("favorite")
+
         label = d.pop("label")
 
         name = d.pop("name")
 
-        favorite = d.pop("favorite", UNSET)
-
         is_default = d.pop("isDefault", UNSET)
 
         annotator = cls(
             engine=engine,
+            favorite=favorite,
             label=label,
             name=name,
-            favorite=favorite,
             is_default=is_default,
         )
 
