@@ -1,14 +1,17 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.doc_alt_text import DocAltText
-from ..models.doc_annotation import DocAnnotation
-from ..models.doc_category import DocCategory
-from ..models.doc_sentence import DocSentence
-from ..models.input_document_metadata import InputDocumentMetadata
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.doc_alt_text import DocAltText
+    from ..models.doc_annotation import DocAnnotation
+    from ..models.doc_category import DocCategory
+    from ..models.doc_sentence import DocSentence
+    from ..models.input_document_metadata import InputDocumentMetadata
+
+
 T = TypeVar("T", bound="InputDocument")
 
 
@@ -17,26 +20,34 @@ class InputDocument:
     """
     Attributes:
         text (str): text of the document
-        annotations (Union[Unset, List[DocAnnotation]]):
-        categories (Union[Unset, List[DocCategory]]):
+        alt_texts (Union[Unset, List['DocAltText']]):
+        annotations (Union[Unset, List['DocAnnotation']]):
+        categories (Union[Unset, List['DocCategory']]):
         identifier (Union[Unset, str]): document identifier
         metadata (Union[Unset, InputDocumentMetadata]): document metadata
-        alt_texts (Union[Unset, List[DocAltText]]):
-        sentences (Union[Unset, List[DocSentence]]):
+        sentences (Union[Unset, List['DocSentence']]):
         title (Union[Unset, str]): title of the document
     """
 
     text: str
-    annotations: Union[Unset, List[DocAnnotation]] = UNSET
-    categories: Union[Unset, List[DocCategory]] = UNSET
+    alt_texts: Union[Unset, List["DocAltText"]] = UNSET
+    annotations: Union[Unset, List["DocAnnotation"]] = UNSET
+    categories: Union[Unset, List["DocCategory"]] = UNSET
     identifier: Union[Unset, str] = UNSET
-    metadata: Union[Unset, InputDocumentMetadata] = UNSET
-    alt_texts: Union[Unset, List[DocAltText]] = UNSET
-    sentences: Union[Unset, List[DocSentence]] = UNSET
+    metadata: Union[Unset, "InputDocumentMetadata"] = UNSET
+    sentences: Union[Unset, List["DocSentence"]] = UNSET
     title: Union[Unset, str] = UNSET
 
     def to_dict(self) -> Dict[str, Any]:
         text = self.text
+        alt_texts: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.alt_texts, Unset):
+            alt_texts = []
+            for alt_texts_item_data in self.alt_texts:
+                alt_texts_item = alt_texts_item_data.to_dict()
+
+                alt_texts.append(alt_texts_item)
+
         annotations: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.annotations, Unset):
             annotations = []
@@ -58,14 +69,6 @@ class InputDocument:
         if not isinstance(self.metadata, Unset):
             metadata = self.metadata.to_dict()
 
-        alt_texts: Union[Unset, List[Dict[str, Any]]] = UNSET
-        if not isinstance(self.alt_texts, Unset):
-            alt_texts = []
-            for alt_texts_item_data in self.alt_texts:
-                alt_texts_item = alt_texts_item_data.to_dict()
-
-                alt_texts.append(alt_texts_item)
-
         sentences: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.sentences, Unset):
             sentences = []
@@ -82,6 +85,8 @@ class InputDocument:
                 "text": text,
             }
         )
+        if alt_texts is not UNSET:
+            field_dict["altTexts"] = alt_texts
         if annotations is not UNSET:
             field_dict["annotations"] = annotations
         if categories is not UNSET:
@@ -90,8 +95,6 @@ class InputDocument:
             field_dict["identifier"] = identifier
         if metadata is not UNSET:
             field_dict["metadata"] = metadata
-        if alt_texts is not UNSET:
-            field_dict["altTexts"] = alt_texts
         if sentences is not UNSET:
             field_dict["sentences"] = sentences
         if title is not UNSET:
@@ -101,9 +104,22 @@ class InputDocument:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.doc_alt_text import DocAltText
+        from ..models.doc_annotation import DocAnnotation
+        from ..models.doc_category import DocCategory
+        from ..models.doc_sentence import DocSentence
+        from ..models.input_document_metadata import InputDocumentMetadata
+
         d = src_dict.copy()
         text = d.pop("text")
 
+        alt_texts = []
+        _alt_texts = d.pop("altTexts", UNSET)
+        for alt_texts_item_data in _alt_texts or []:
+            alt_texts_item = DocAltText.from_dict(alt_texts_item_data)
+
+            alt_texts.append(alt_texts_item)
+
         annotations = []
         _annotations = d.pop("annotations", UNSET)
         for annotations_item_data in _annotations or []:
@@ -127,13 +143,6 @@ class InputDocument:
         else:
             metadata = InputDocumentMetadata.from_dict(_metadata)
 
-        alt_texts = []
-        _alt_texts = d.pop("altTexts", UNSET)
-        for alt_texts_item_data in _alt_texts or []:
-            alt_texts_item = DocAltText.from_dict(alt_texts_item_data)
-
-            alt_texts.append(alt_texts_item)
-
         sentences = []
         _sentences = d.pop("sentences", UNSET)
         for sentences_item_data in _sentences or []:
@@ -145,11 +154,11 @@ class InputDocument:
 
         input_document = cls(
             text=text,
+            alt_texts=alt_texts,
             annotations=annotations,
             categories=categories,
             identifier=identifier,
             metadata=metadata,
-            alt_texts=alt_texts,
             sentences=sentences,
             title=title,
         )
