@@ -1,10 +1,13 @@
-from typing import Any, Dict, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union
 
 import attr
 
-from ..models.sherpa_job_bean import SherpaJobBean
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.sherpa_job_bean import SherpaJobBean
+
+
 T = TypeVar("T", bound="ProjectStatus")
 
 
@@ -19,7 +22,7 @@ class ProjectStatus:
 
     project_name: str
     status: str
-    pending_job: Union[Unset, SherpaJobBean] = UNSET
+    pending_job: Union[Unset, "SherpaJobBean"] = UNSET
 
     def to_dict(self) -> Dict[str, Any]:
         project_name = self.project_name
@@ -42,6 +45,8 @@ class ProjectStatus:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.sherpa_job_bean import SherpaJobBean
+
         d = src_dict.copy()
         project_name = d.pop("projectName")
 
