@@ -4,9 +4,10 @@ from enum import Enum
 class SherpaJobBeanType(str, Enum):
     DOC_IMPORT = "DOC_IMPORT"
     EXPERIMENT_TRAINING = "EXPERIMENT_TRAINING"
-    DOC_DELETION = "DOC_DELETION"
+    DELETE_DOCS = "DELETE_DOCS"
     CORPUS_ANNOTATE = "CORPUS_ANNOTATE"
     TRAIN_AND_SUGGEST = "TRAIN_AND_SUGGEST"
+    ADD_METADATA = "ADD_METADATA"
     UNSPECIFIED = "UNSPECIFIED"
     PROJECT_INDEXING = "PROJECT_INDEXING"
     PROJECTS_INDEXING = "PROJECTS_INDEXING"
@@ -15,6 +16,9 @@ class SherpaJobBeanType(str, Enum):
     PROCESS_CANDIDATES = "PROCESS_CANDIDATES"
     SYNCHRONIZE_TERMS = "SYNCHRONIZE_TERMS"
     TERM_IMPORT = "TERM_IMPORT"
+    SPLIT_CORPUS = "SPLIT_CORPUS"
+    BACKUP_USER_SESSION = "BACKUP_USER_SESSION"
+    ADD_CATEGORY = "ADD_CATEGORY"
 
     def __str__(self) -> str:
         return str(self.value)
