@@ -9,34 +9,46 @@ T = TypeVar("T", bound="UserProfileUpdate")
 
 @attr.s(auto_attribs=True)
 class UserProfileUpdate:
-    """ """
+    """
+    Attributes:
+        email (Union[Unset, str]):
+        password (Union[Unset, str]):
+        profilename (Union[Unset, str]):
+    """
 
-    profilename: Union[Unset, str] = UNSET
+    email: Union[Unset, str] = UNSET
     password: Union[Unset, str] = UNSET
+    profilename: Union[Unset, str] = UNSET
 
     def to_dict(self) -> Dict[str, Any]:
-        profilename = self.profilename
+        email = self.email
         password = self.password
+        profilename = self.profilename
 
         field_dict: Dict[str, Any] = {}
         field_dict.update({})
-        if profilename is not UNSET:
-            field_dict["profilename"] = profilename
+        if email is not UNSET:
+            field_dict["email"] = email
         if password is not UNSET:
             field_dict["password"] = password
+        if profilename is not UNSET:
+            field_dict["profilename"] = profilename
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        profilename = d.pop("profilename", UNSET)
+        email = d.pop("email", UNSET)
 
         password = d.pop("password", UNSET)
 
+        profilename = d.pop("profilename", UNSET)
+
         user_profile_update = cls(
-            profilename=profilename,
+            email=email,
             password=password,
+            profilename=profilename,
         )
 
         return user_profile_update
